function [ dWdT ] = computeDWDTheta( thetas, d, D, W0 )
%
% This is equation 43 (computed for {\em all} k)
% --checked (2005-11-12) ... (2005-11-14) bug in derivative calculation found
% 
% Written by:
% -- 
% John L. Weatherwax                2005-10-30
% 
% email: wax@alum.mit.edu
% 
% Please send comments and especially bug reports to the
% above email address.
% 
%-----
  
if( nargin < 4 ) 
  W0 = eye(D,d);
end
  
% Compute dWdTheta: 
%
dWdT = []; 
for k=1:d*(D-d),
  dWdTk = W0; 
  for i=d*(D-d):-1:1,
    o=floor((i-1)/(D-d))+1; u=mod(i-1,D-d)+d+1;
    if( i~=k ) % Non-derivative term
      G1=eye(D); 
      G1(o,o) =  cos(thetas(i)); G1(o,u) = sin(thetas(i)); G1(u,o) = -sin(thetas(i)); G1(u,u) =  cos(thetas(i)); 
    else       % Derivative term
      G1=zeros(D); 
      G1(o,o) = -sin(thetas(i)); G1(o,u) = cos(thetas(i)); G1(u,o) = -cos(thetas(i)); G1(u,u) = -sin(thetas(i)); 
    end
    dWdTk = G1 * dWdTk;
  end
  dWdT = [ dWdT, dWdTk ]; 
end
